@@ -2,8 +2,10 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "메일",
+    "Loading accounts" : "계정 불러오는 중",
     "Error while loading the accounts." : "계정을 불러오는 중 오류가 발생했습니다.",
     "Error while loading the selected account." : "선택한 계정을 불러오는 중 오류가 발생했습니다.",
+    "Can not load this folder." : "이 폴더를 불러올 수 없습니다.",
     "Searching for {query}" : "{query} 검색",
     "Error while deleting message." : "메시지를 삭제하는 중 오류가 발생했습니다.",
     "Forwarded message" : "전달된 메시지",
@@ -16,6 +18,7 @@ OC.L10N.register(
     "Could not move message." : "메시지를 이동할 수 없습니다.",
     "Invalid account" : "잘못된 계정",
     "Invalid folder" : "잘못된 폴더",
+    "Error while creating the account: " : "계정 생성 중 오류 발생:",
     "Unknown error" : "알 수 없는 오류",
     "All inboxes" : "모든 받은 편지함",
     "you" : "나",
@@ -27,10 +30,14 @@ OC.L10N.register(
     "Unable to load the desired message" : "원하는 메시지를 불러올 수 없음",
     "There was a problem loading the message" : "메시지를 불러오는 중 문제가 발생했습니다",
     "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["새 메일 %n개\n보낸 사람: {from}"],
+    "Nextcloud Mail" : "Nextcloud 메일",
+    "Save" : "저장",
     "Show all folders" : "모든 폴더 보기",
     "Collapse folders" : "폴더 접기",
     "Error while deleting account." : "계정을 삭제하는 중 오류가 발생했습니다.",
     "Choose a file to add as attachment" : "첨부할 파일을 선택하십시오",
+    "An error occurred while uploading {fname}" : "{fname}을 업로드하는 중 오류 발생",
     "Reply" : "답장",
     "Send" : "보내기",
     "Sending …" : "보내는 중...",
@@ -39,10 +46,12 @@ OC.L10N.register(
     "An unknown error occurred" : "알 수 없는 오류가 발생했습니다",
     "Opening HTML drafts is not supported yet." : "HTML 임시 보관 메시지를 여는 것은 지원되지 않습니다.",
     "Draft saved!" : "임시 보관함에 저장했습니다!",
-    "No writable calendars found" : "쓰기 가능한 달력을 찾을 수 없음",
-    "Error while importing the calendar event" : "달력 이벤트를 가져 오는 중 오류 발생",
-    "Error while downloading calendar event" : "달력 이벤트 다운로드 중 오류 발생",
+    "No writable calendars found" : "기록할 수 있는 달력을 찾을 수 없음",
+    "Error while importing the calendar event" : "달력 행사를 가져 오는 중 오류 발생",
+    "Error while downloading calendar event" : "달력 행사를 다운로드하는 중 오류 발생",
     "Error while loading messages." : "메시지를 불러오는 중 오류가 발생했습니다.",
+    "Error while refreshing messages." : "메시지를 새로 고치는 중 오류가 발생했습니다.",
+    "Setting up your account" : "계정 설정 중",
     "Inbox" : "받은 편지함",
     "Sent" : "보낸 편지함",
     "Drafts" : "임시 보관함",
@@ -59,17 +68,27 @@ OC.L10N.register(
     "Settings" : "설정",
     "Forwarding to %s" : "%s 전달",
     "Click here if you are not automatically redirected within the next few seconds." : "자동으로 이동하지 않는 경우 여기를 클릭하십시오.",
-    "Redirect" : "리디렉션",
-    "The link leads to %s" : "링크는 %s(으)로 연결",
+    "Redirect" : "넘겨주기",
+    "The link leads to %s" : "이 링크가 %s을(를) 향함",
     "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "해당 페이지를 방문하지 않으려면 <a href=\"%s\">메일</a>로 돌아갈 수 있습니다.",
     "Continue to %s" : "%s(으)로 이동",
     "Delete account" : "계정 삭제",
+    "Try again" : "다시 시도",
     "New message" : "새로운 메시지",
     "Account Settings" : "계정 설정",
     "Aliases" : "별칭",
     "Mail address" : "메일 주소",
     "Display Name" : "표시 이름",
-    "Save" : "저장",
+    "Keyboard shortcuts" : "키보드 단축키",
+    "Speed up your Mail experience with these quick shortcuts." : "빠른 단축키로 메일 사용을 더 빠르게 할 수 있습니다.",
+    "Compose new message" : "새 메시지 작성",
+    "Newer message" : "새로운 메시지",
+    "Older message" : "오래된 메시지",
+    "Toggle star" : "별표 전환",
+    "Toggle unread" : "읽음/읽지 않음 전환",
+    "Delete" : "삭제",
+    "Search" : "검색",
+    "Refresh" : "새로 고침",
     "Connect your mail account" : "메일 계정에 연결",
     "Name" : "이름",
     "Mail Address" : "메일 주소",
@@ -95,10 +114,14 @@ OC.L10N.register(
     "Subject" : "제목",
     "Save all to Files" : "모두 저장",
     "Add mail account" : "메일 계정 추가",
+    "Use Gravatar and favicon avatars" : "Gravatar 및 파비콘 아바타 사용",
     "No search results for" : "다음에 대한 검색 결과 없음",
     "The images have been blocked to protect your privacy." : "개인 정보를 보호하기 위해 사진을 차단했습니다.",
     "Show images from this sender" : "이 발신자의 사진 표시",
     "Forward" : "전달",
+    "No messages in this folder!" : "이 폴더에 메시지가 없습니다!",
+    "Upload attachment" : "첨부 파일 업로드",
+    "Add attachment from Files" : "파일 앱에서 첨부 파일 추가",
     "Import into calendar" : "달력으로 가져오기",
     "Download attachment" : "첨부 파일 다운로드",
     "Save to Files" : "파일에 저장"
