@@ -32,6 +32,7 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nieuw bericht \nvan {from}","%n niewe berichten \nvan {from}"],
     "Nextcloud Mail" : "Nextcloud E-mail",
+    "Save" : "Opslaan",
     "Show all folders" : "Laat alle mappen zien",
     "Collapse folders" : "Mappen inklappen",
     "Error while deleting account." : "Fout bij verwijderen account.",
@@ -69,7 +70,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klik hier als je binnen enkele seconden niet automatisch wordt doorgestuurd.",
     "Redirect" : "Omleiden",
     "The link leads to %s" : "De link verwijst naar %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Als u die pagina niet wilt bezoeken, kunt u teruggaan naar <a href=\"%s\">E-mail</a>.",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Als je die pagina niet wilt bezoeken, kun je teruggaan naar <a href=\"%s\">E-mail</a>.",
     "Continue to %s" : "Verder naar %s",
     "Delete account" : "Verwijder account",
     "Try again" : "Probeer opnieuw",
@@ -78,7 +79,6 @@ OC.L10N.register(
     "Aliases" : "Aliassen",
     "Mail address" : "E-mailadres",
     "Display Name" : "Weergavenaam",
-    "Save" : "Opslaan",
     "Keyboard shortcuts" : "Sneltoetsen",
     "Speed up your Mail experience with these quick shortcuts." : "Versnel je e-mail-ervaring met deze handige snelkoppelingen.",
     "Compose new message" : "Opstellen nieuw bericht",
@@ -114,8 +114,9 @@ OC.L10N.register(
     "Subject" : "Onderwerp",
     "Save all to Files" : "Sla alles op in Bestanden",
     "Add mail account" : "Voeg e-mail account toe",
+    "Use Gravatar and favicon avatars" : "Gebruik Gravatar en favicon avatars",
     "No search results for" : "Geen resultaten gevonden voor",
-    "The images have been blocked to protect your privacy." : "De afbeeldingen zijn geblokkeerd om jouw privacy te beschermen",
+    "The images have been blocked to protect your privacy." : "De afbeeldingen zijn geblokkeerd om je privacy te beschermen",
     "Show images from this sender" : "Laat afbeeldingen zien van deze afzender",
     "Forward" : "Doorsturen",
     "No messages in this folder!" : "Geen berichten in deze map!",
